@@ -21,7 +21,7 @@ NULL
 bootstrap <- function(data, n, id = ".id") {
   bootstrap <- purrr::rerun(n, resample_bootstrap(data))
 
-  df <- tibble::data_frame(strap = bootstrap)
+  df <- tibble::tibble(strap = bootstrap)
   df[[id]] <- id(n)
   df
 }
